import React, { Component } from 'react';
import { Container, Row, Col } from "react-bootstrap";
import { makeStyles, createMuiTheme, MuiThemeProvider } from '@material-ui/core/styles';
import { TextField, InputBase } from "@material-ui/core";
import { ExcelRenderer } from 'react-excel-renderer';
import Images from '../../assets/Images';
import MUIDataTable from "mui-datatables";
import UploadFile from "../../library/Upload";
import CreateApprovalMatrix from "./CreateApprovalMatrix";
import EditApprovalMatrix from "./EditApprovalMatrix";
import VisualisasiAM from "./VisualisasiAM";
import api from "../../api";

var ct = require("../../library/CustomTable");
const getMuiTheme = () => createMuiTheme(ct.customTable());
const options = ct.customOptions();
const options2 = ct.customOptions2();

export default class ApprovalMatrix extends Component {
    constructor(props) {
        super(props)
        this.state = {
            visibleAM: true,
            visibleCreate: false,
            visibleEdit: false,
            visibleVisual: false,
            dataTable: [],
            listData: [],
            data: [],
            search: "",
            cols: null,
            rows: null,
            dataLoaded: false
        }
        this.fileHandler = this.fileHandler.bind(this);
    }

    fileHandler = (event) => {
        let fileObj = event
        ExcelRenderer(fileObj, (err, resp) => {
            if (err) {
                // console.log(err);
            }
            else {
                let judul = resp.rows[0]
                let isi = resp.rows.slice(1)
                // let body = isi.map((item) => {
                //     return {
                //         item
                //     ]
                // })
                // console.log(JSON.stringify(isi));
                this.setState({
                    dataLoaded: true,
                    cols: judul,
                    rows: isi
                });
            }
        });
    }

    componentDidMount() {
        this.getData()
        console.log(this.props.height)
    }

    getData() {
        api.create().getAM().then((response) => {
            // console.log(response)
            if(response.status == null){
                alert(response.problem)
            }
            else if (response.data.status == 'success') {
                let data = response.data.data
                let listData = data.sort((a,b) => a.approval_matrix_id - b.approval_matrix_id).map((item, index) => {
                    return [index, item.approval_matrix_id, item.approval_type_name, item.orders, item.fullname, item.operator_type_name, item.status ]
                })
                this.setState({ dataTable: listData, listData: response.data.data })
            } else {
                alert(response.data.message)
            }
        })
    }

    openPopUp(index, type) {
        if (type === 'edit') {
            this.setState({
                selectIndex: index,
                visibleEdit: true
            })
        } else {
            this.setState({
                data: this.state.listData[index],
                visibleCreate: true
            })
        }
    }

    handleInputChange(e) {
        this.setState({ search: e })
        let body = {
            "keyword": e
        }
        api.create().searchAM(body).then(response => {
            // console.log(response.data);
            if (response.data.status == 'success') {
                let data = response.data.data
                let listData = data.map((item, index) => {
                    return [index, item.approval_matrix_id, item.approval_type_name, item.orders, item.fullname, item.operator_type_name, item.status]
                })
                this.setState({ dataTable: listData, listData: response.data.data })
            } else {
                alert(response.data.message)
            }
        })
    }

    createAM = (payload) => {
        this.setState({ visibleCreate: false })
        api.create().createAM(payload).then(response => {
            if (response.data.status == 'success') {
                this.getData()
            } else {
                alert(response.data.message)
            }
        })
    }

    updateAM = (payload) => {
        this.setState({ visibleEdit: false })
        api.create().updateAM(payload).then(response => {
            if (response.data.status == 'success') {
                this.getData()
            } else {
                alert(response.data.message)
            }
        })
    }

    downloadFile = async () => {
        let res = await fetch(
            "https://tia.eksad.com/tia-reporting-dev/public/attachment/download_file?fileName=ApprovalMatrixTemplate&&fileType=xlsx"
        )
        res = await res.blob()
        console.log(res)
        if (res.size > 0) {
            let url = window.URL.createObjectURL(res);
            let a = document.createElement('a');
            a.href = url;
            a.download = 'Template Approval Matrix.xlsx';
            a.click();
        }
    }

    downloadDataTable = async () => {
        alert('link belum ada')
        // let res = await fetch(
        //     "https://tia.eksad.com/tia-reporting-dev/public/business_unit/export_business_unit"
        // )
        // res = await res.blob()
        // console.log(res)
        // if (res.size > 0) {
        //     let url = window.URL.createObjectURL(res);
        //     let a = document.createElement('a');
        //     a.href = url;
        //     a.download = 'Business Unit.xlsx';
        //     a.click();
        // }
    }

    render() {
        const columns = [{
            name: "Action",
            options: {
                customBodyRender: (val, tableMeta) => {
                    return (
                        <div style={{ display: 'flex' }}>
                            <button
                                style={{
                                    backgroundColor: 'transparent',
                                    cursor: 'pointer',
                                    borderColor: 'transparent'
                                }}
                                onClick={() => this.openPopUp(tableMeta.rowIndex, 'edit')}
                                // onClick={() => this.setState({ visibleEdit: true })}
                            >
                                <img src={Images.editCopy} />
                            </button>
                        </div >
                    );
                }
            }
        }, 
        {
            name: "ID",
            options: {
                customBodyRender: (val, tableMeta) => {
                    return (
                        <div style={{ display: 'flex' }}>
                            <span style={{ color: tableMeta.rowData[6] === "Aktif" ? "#656565" : 'rgba(0, 0, 0, 0.25)' }}>{val}</span>
                        </div >
                    );
                }
            }
        }, 
        {
            name: "Tipe Persetujuan",
            options: {
                customBodyRender: (val, tableMeta) => {
                    return (
                        <div style={{ display: 'flex' }}>
                            <span style={{ color: tableMeta.rowData[6] === "Aktif" ? "#656565" : 'rgba(0, 0, 0, 0.25)' }}>{val}</span>
                        </div >
                    );
                }
            } 
        },
        {
            name: "Order",
            options: {
                customBodyRender: (val, tableMeta) => {
                    return (
                        <div style={{ display: 'flex' }}>
                            <span style={{ color: tableMeta.rowData[6] === "Aktif" ? "#656565" : 'rgba(0, 0, 0, 0.25)' }}>{val}</span>
                        </div >
                    );
                }
            } 
        },
        {
            name: "Nama Pemberi Persetujuan",
            options: {
                customBodyRender: (val, tableMeta) => {
                    return (
                        <div style={{ display: 'flex' }}>
                            <span style={{ color: tableMeta.rowData[6] === "Aktif" ? "#656565" : 'rgba(0, 0, 0, 0.25)' }}>{val}</span>
                        </div >
                    );
                }
            }
        },
        {
            name: "Operator",
            options: {
                customBodyRender: (val, tableMeta) => {
                    return (
                        <div style={{ display: 'flex' }}>
                            <span style={{ color: tableMeta.rowData[6] === "Aktif" ? "#656565" : 'rgba(0, 0, 0, 0.25)' }}>{val}</span>
                        </div >
                    );
                }
            }
        },
        {
            name: "Status",
            options: {
                customBodyRender: (val, tableMeta) => {
                    return (
                        <div style={{ display: 'flex' }}>
                            <span style={{ color: tableMeta.rowData[6] === "Aktif" ? "#656565" : 'rgba(0, 0, 0, 0.25)' }}>{val}</span>
                        </div >
                    );
                }
            }
        }]
        const data = [
            ["", "1", "Yearly", "1", "John Doe", "-", "Aktif"],
            ["", "2", "Yearly", "2", "John Doe", "-", "Aktif"],
            ["", "3", "Yearly", "2", "John Doe", "AND", "Aktif"],
            ["", "4", "Yearly", "2", "John Doe", "AND", "Non Aktif"],
            ["", "5", "Yearly", "3", "John Doe", "-", "Non Aktif"],
        ]

        return (
            <div>
                {this.state.visibleAM === true ?
                    <div style={{ height: this.props.height }}>
                        <div class="main-color" style={{ height: 199, width: '100%'}} />
                        <div>    
                            <div style={{ display: 'flex', flexDirection: 'row', justifyContent: 'space-between', paddingRight: 25, paddingLeft: 25, marginTop: -150 }}>
                                <label style={{ width: '20%', color: 'white', fontSize: 16, alignSelf: 'center', paddingTop: 8 }}>Master Data - Approval Matrix</label>
                                <div style={{ color: 'white', width: '50%', height: 37, display: 'flex', backgroundColor: 'white', borderWidth: 2, alignItems: 'center', borderRadius: 6, paddingLeft: 5, paddingRight: 5, alignSelf: 'center' }}>
                                    <img src={Images.searchBlack} style={{ marginRight: 10 }} />
                                    <InputBase
                                        style={{ width: '100%' }}
                                        placeholder="Search"
                                        value={this.state.search}
                                        onChange={(e) => this.handleInputChange(e.target.value)}
                                        inputProps={{ 'aria-label': 'naked' }}
                                    />
                                </div>
                                <div style={{ width: '30%', justifyContent: 'flex-end', display: 'flex', flexFlow: 'wrap' }}>
                                    <button
                                        style={{
                                            backgroundColor: 'transparent',
                                            cursor: 'pointer',
                                            borderColor: 'transparent',
                                            padding: 0,
                                            margin: 5
                                        }}
                                        onClick={() => this.downloadFile()}
                                    >
                                        <img src={Images.template} />
                                    </button>
                                    <button
                                        style={{
                                            backgroundColor: 'transparent',
                                            cursor: 'pointer',
                                            borderColor: 'transparent',
                                            marginLeft: 16,
                                            padding:0,
                                            margin: 5
                                        }}
                                        onClick={() => this.setState({ visibleUpload: true })}
                                    >
                                        <img src={Images.upload} />
                                    </button>
                                    <button
                                        style={{
                                            backgroundColor: 'transparent',
                                            cursor: 'pointer',
                                            borderColor: 'transparent',
                                            marginLeft: 16,
                                            padding:0,
                                            margin: 5
                                        }}
                                        onClick={() => this.downloadDataTable()}
                                    >
                                        <img src={Images.download} />
                                    </button>
                                    <button
                                        style={{
                                            backgroundColor: 'transparent',
                                            cursor: 'pointer',
                                            borderColor: 'transparent',
                                            marginLeft: 16,
                                            padding:0,
                                            margin: 5
                                        }}
                                        onClick={() => this.setState({ visibleVisual: true, visibleAM: false })}
                                    >
                                        <img src={Images.visualisasi} />
                                    </button>
                                    <button
                                        style={{
                                            backgroundColor: 'transparent',
                                            cursor: 'pointer',
                                            borderColor: 'transparent',
                                            marginLeft: 16,
                                            padding:0,
                                            margin: 5
                                        }}
                                        onClick={() => this.setState({ visibleCreate: true })}
                                    >
                                        <img src={Images.add} />
                                    </button>
                                </div >
                            </div>
                            <div style={{ padding: 25, width: '100%' }}>
                                <MuiThemeProvider theme={getMuiTheme()}>
                                    <MUIDataTable
                                        theme={getMuiTheme()}
                                        data={this.state.dataTable}
                                        columns={columns}
                                        options={options}
                                    />
                                </MuiThemeProvider>
                            </div>
                        </div>
                    </div>
                    :
                    this.state.visibleVisual == true ?
                    <VisualisasiAM
                        onClickClose={() => this.setState({ visibleVisual: false, visibleAM: true })}
                        height= {this.props.height}
                    />
                    :
                    <div style={{ height: this.props.height }}>
                        <div class="main-color" style={{ height: 199, width: '100%' }} />
                        <div> 
                            <div>
                                <div style={{ display: 'flex', flexDirection: 'row', justifyContent: 'space-between', paddingRight: 25, paddingLeft: 25, marginTop: -150 }}>
                                    <label style={{ color: 'white', fontSize: 16, alignSelf: 'center' }}>Preview Data</label>
                                </div>
                                <div style={{ padding: 25 }}>
                                    {this.state.dataLoaded && (
                                        <MuiThemeProvider theme={getMuiTheme()}>
                                            <MUIDataTable
                                                theme={getMuiTheme()}
                                                data={this.state.rows}
                                                columns={this.state.cols}
                                                options={options}
                                            />
                                        </MuiThemeProvider>
                                    )}
                                </div>
                                <div style={{ display: 'flex', width: '100%', placeContent: 'flex-end', padding: 20 }}>
                                    <button
                                        type="button"
                                        onClick={() => this.setState({ visibleAM: true })}
                                        style={{ marginRight: 20}}
                                    >
                                        <div style={{ width: 102, height: 30, border: 'solid 1px #354960', borderRadius: 5, alignItems: 'center', display: 'flex', justifyContent: 'center' }}>
                                            <span style={{ color: '#354960', fontSize: 11 }}>Batal</span>
                                        </div>
                                    </button>
                                    <div style={{ width: 102, height: 30, backgroundColor: '#354960', borderRadius: 5, alignItems: 'center', display: 'flex', justifyContent: 'center' }}>
                                        <span style={{ color: '#fff', fontSize: 11 }}>Simpan</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                }

                {this.state.visibleCreate && (
                    <CreateApprovalMatrix
                        onClickClose={() => this.setState({ visibleCreate: false })}
                        data={this.state.listData}
                        createAM={this.createAM.bind(this)}
                    />
                )}
                {this.state.visibleEdit && (
                    <EditApprovalMatrix
                        type={"edit"}
                        onClickClose={() => this.setState({ visibleEdit: false })}
                        data={this.state.listData[this.state.selectIndex]}
                        updateAM={this.updateAM.bind(this)}
                    />
                )}
                {this.state.visibleUpload && (
                    <div className="test app-popup-show">
                        <div className="popup-content background-white border-radius" style={{ borderRadius: 8 }}>
                            <div className="popup-panel grid grid-2x" style={{ backgroundColor: '#51c6ea', height: 64, borderTopRightRadius: 8, borderTopLeftRadius: 8 }}>
                                <div className="col-1" style={{ maxWidth: "inherit", display: 'flex', alignItems: 'center' }}>
                                    <div className="popup-title">
                                        <span style={{ color: '#fff', fontSize: 16, fontWeight: 'bold' }}>Upload File</span>
                                    </div>
                                </div>
                                <div className="col-2 content-right" style={{ maxWidth: "inherit", alignSelf: 'center' }}>
                                    <button
                                        type="button"
                                        className="btn btn-circle btn-white"
                                        onClick={() => this.setState({ visibleUpload: false })}
                                    >
                                        <i className="fa fa-lg fa-times" style={{ color: 'white' }} />
                                    </button>
                                </div>
                            </div>
                            <UploadFile
                                type={this.state.uploadStatus}
                                percentage={this.state.percentage}
                                result={this.state.result}
                                acceptedFiles={["pdf"]}
                                onHandle={(dt) => {
                                    this.fileHandler(dt)
                                    this.setState({ uploadStatus: 'idle', percentage: '0' })
                                }}
                                onUpload={() => this.setState({ visibleUpload: false, visibleAM: false })}
                            />
                        </div>
                    </div>
                )}
            </div>
        );
    }
}
