import React, { Component } from 'react';
import { TextField, Typography } from '@material-ui/core';
import { DateTimePicker, KeyboardDatePicker, DatePicker } from "@material-ui/pickers";
import Autocomplete from '@material-ui/lab/Autocomplete';
import * as R from 'ramda'
import format from "date-fns/format";
import localeID from "date-fns/locale/id"
import api from "../../api";

export default class CreateApprovalMatrix extends Component {
    constructor(props) {
        super(props)
        this.state = {
            userId: null,
            typeId: null,
            operatorId: null,
            order: '',
            approvedBy: null,
            types: null,
            operators: null,
            startDate: '',
            endDate: '',
            userData: [],
            value: null,
            date: new Date()
        }
    }

    componentDidMount() {
        this.getUserData()
        this.getTypeData()
        this.getOperatorData()
    }

    getUserData() {
        api.create().getApprovedByAM().then((response) => {
            if (response.data.status == 'success') {
                let data = response.data.data
                let userData = data.map((item) => {
                    return {
                        user_id: item.user_id,
                        fullname: item.fullname
                    }
                })
                // console.log(userData)
                let defaultProps = {
                    options: userData,
                    getOptionLabel: (option) => option.fullname,
                  };
                this.setState({ approvedBy: defaultProps, userData: response.data.data})
            } else {
                alert(response.data.message)
            }
        })
    }

    getTypeData() {
        api.create().getTypeAM().then((response) => {
            if (response.data.status == 'success') {
                let data = response.data.data
                let typeData = data.map((item) => {
                    return {
                        approval_type_id: item.approval_type_id,
                        approval_type_name: item.approval_type_name
                    }
                })
                let typeProps = {
                    options: typeData,
                    getOptionLabel: (option) => option.approval_type_name,
                  };
                this.setState({ types: typeProps, typeData: response.data.data })
            } else {
                alert(response.data.message)
            }
        })
    }

    getOperatorData() {
        api.create().getOperatorAM().then((response) => {
            if (response.data.status == 'success') {
                let data = response.data.data
                let operatorData = data.map((item) => {
                    return {
                        operator_type_id: item.operator_type_id,
                        operator_type_name: item.operator_type_name
                    }
                })
                // console.log(userData)
                let operatorProps = {
                    options: operatorData,
                    getOptionLabel: (option) => option.operator_type_name,
                  };
                this.setState({ operators: operatorProps, operatorData: response.data.data })
            } else {
                alert(response.data.message)
            }
        })
    }
    

    handleChange(e, type) {
        let data = this.state
        let isDate = type !== '' ? true : false
        if (isDate && type == 'start_date') {
            this.setState({ startDate: format(e, 'yyyy-MM-dd') }, () => {
                // console.log(this.state.startDate)
            })
        } else if (isDate && type == 'end_date') {
            this.setState({ endDate: format(e, 'yyyy-MM-dd') }, () => {
                // console.log(this.state.endDate)
            })
        } else {
            // this.setState({...data, tempData: {...this.state.tempData, [e.target.name] :  e.target.value}})
        }

    }

    validasi() {
        if (R.isNil(this.state.typeId)) return alert("Tipe Persetujuan is Required.");
        if (R.isEmpty(this.state.order)) return alert("Order is Required.");
        if (R.isNil(this.state.userId)) return alert("Pemberi Persetujuan is Required.");
        if (R.isNil(this.state.operatorId)) return alert("Operator is Required.");
        if (!R.isEmpty(this.state.startDate) && !R.isEmpty(this.state.endDate) && (this.state.startDate > this.state.endDate)) return alert("Masa Berlaku Tidak Boleh Kurang Dari Tanggal Mulai");
        if (R.isEmpty(this.state.startDate)) return alert("Tanggal Mulai is Required.");
        if (R.isEmpty(this.state.endDate)) return alert("Tanggal Berakhir is Required.");
        console.log('masuk');
        let payload = {
            "approval_type_id": this.state.typeId,
            "orders": this.state.order,
            "user_id": this.state.userId,
            "operator_type_id": this.state.operatorId,
            "start_date": this.state.startDate,
            "end_date": this.state.endDate
        }
        this.props.createAM(payload)
        // console.log(payload)

    }

    render() {
        return (
            <div className="test app-popup-show" style={{ paddingTop: 100 }}>
                <div className="popup-content background-white border-radius" style={{ borderRadius: 8 }}>
                    <div className="popup-panel grid grid-2x" style={{ backgroundColor: '#51c6ea', height: 64, borderTopRightRadius: 8, borderTopLeftRadius: 8 }}>
                        <div className="col-1" style={{ maxWidth: "inherit", display: 'flex', alignItems: 'center' }}>
                            <div className="popup-title">
                                <span style={{ color: '#fff', fontSize: 16, fontWeight: 'bold' }}>Tambah Data</span>
                            </div>
                        </div>
                        <div className="col-2 content-right" style={{ maxWidth: "inherit", alignSelf: 'center' }}>
                            <button
                                type="button"
                                className="btn btn-circle btn-white"
                                onClick={() => this.props.onClickClose()}
                            >
                                <i className="fa fa-lg fa-times" style={{ color: 'white' }} />
                            </button>
                        </div>
                    </div>

                    <div className="border-bottom" style={{ padding: 20 }}>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="" style={{ backgroundColor: '#e8e8e8', padding: 10, borderRadius: 5 }}>
                                    <TextField
                                        style={{ width: '100%', height: '90%' }}
                                        id="id"
                                        label="ID"
                                        disabled
                                        inputProps={{
                                            style: {
                                                fontSize: 11
                                            }
                                        }}
                                        InputLabelProps={{
                                            style: {
                                                fontSize: 11,
                                                color: '#7e8085'
                                            }
                                        }}
                                    >
                                    </TextField>
                                </div>
                            </div>
                            <div className="column-2">
                                <div className="" style={{ padding: 10, borderRadius: 5 }}>
                                    <Autocomplete
                                        {...this.state.types}
                                        id="tipe"
                                        onChange={(event, newInputValue) => this.setState({typeId:newInputValue.approval_type_id})}
                                        disableClearable
                                        renderInput={(params) => <TextField {...params} label="Tipe Persetujuan" />}
                                        // inputProps={{
                                        //     style: {
                                        //         fontSize: 11
                                        //     }
                                        // }}
                                        // InputLabelProps={{
                                        //     style: {
                                        //         fontSize: 11,
                                        //         color: '#7e8085'
                                        //     }
                                        // }}
                                    />
                                </div>
                            </div>
                        </div>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                    <TextField
                                        style={{ width: '100%' }}
                                        id="order"
                                        label="Order"
                                        value={this.state.order}
                                        onChange={(e) => this.setState({ order: e.target.value })}
                                        inputProps={{
                                            style: {
                                                fontSize: 11
                                            }
                                        }}
                                        InputLabelProps={{
                                            style: {
                                                fontSize: 11,
                                                color: '#7e8085'
                                            }
                                        }}
                                    >
                                    </TextField>
                                </div>
                            </div>
                            <div className="column-2">
                                <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                <Autocomplete
                                    // margin="normal"
                                    {...this.state.approvedBy}
                                    id="approvedby"
                                    onChange={(event, newInputValue) => this.setState({userId:newInputValue.user_id})}
                                    disableClearable
                                    renderInput={(params) => <TextField {...params} label="Pemberi Persetujuan" />}
                                    // value={this.state.value}
                                    // inputProps={{
                                    //     style: {
                                    //         fontSize: 11
                                    //     }
                                    // }}
                                    // InputLabelProps={{
                                    //     style: {
                                    //         fontSize: 11,
                                    //         color: '#7e8085'
                                    //     }
                                    // }}
                                    // style={{ padding: 0, margin: 0, width: '100%'}}
                                />
                                </div>
                            </div>
                        </div>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                    <Autocomplete
                                        {...this.state.operators}
                                        // margin="normal"
                                        id="operator"
                                        disableClearable
                                        onChange={(event, newInputValue) => this.setState({operatorId:newInputValue.operator_type_id})}
                                        renderInput={(params) => <TextField {...params} label="Operator" />}
                                        // value={this.state.value}
                                        // inputProps={{
                                        //     style: {
                                        //         fontSize: 11
                                        //     }
                                        // }}
                                        // InputLabelProps={{
                                        //     style: {
                                        //         fontSize: 11,
                                        //         color: '#7e8085'
                                        //     }
                                        // }}
                                        // style={{ padding: 0, margin: 0, width: '100%' }}
                                    />
                                </div>
                            </div>
                            <div className="column-2">
                                
                            </div>
                        </div>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                <DatePicker
                                    margin="normal"
                                    id="startDate"
                                    label="Berlaku Mulai"
                                    format="dd MMMM yyyy"
                                    value={this.state.startDate == "" ? null : this.state.startDate}
                                    onChange={(e) => this.handleChange(e, 'start_date')}
                                    KeyboardButtonProps={{
                                        'aria-label': 'change date',
                                    }}
                                    inputProps={{
                                        style: {
                                            fontSize: 11
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            color: '#7e8085'
                                        }
                                    }}
                                    style={{ padding: 0, margin: 0, width: '100%' }}
                                />
                                </div>
                            </div>
                            <div className="column-2">
                                <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                <DatePicker
                                    margin="normal"
                                    id="endDate"
                                    label="Berlaku Hingga"
                                    format="dd MMMM yyyy"
                                    value={this.state.endDate == "" ? null : this.state.endDate}
                                    onChange={(e) => this.handleChange(e, 'end_date')}
                                    KeyboardButtonProps={{
                                        'aria-label': 'change date',
                                    }}
                                    inputProps={{
                                        style: {
                                            fontSize: 11
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            color: '#7e8085'
                                        }
                                    }}
                                    style={{ padding: 0, margin: 0, width: '100%' }}
                                />
                                </div>
                            </div>
                        </div>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="margin-top-10px" style={{ backgroundColor: '#e8e8e8', padding: 10, borderRadius: 5 }}>
                                    <TextField
                                        style={{ width: '100%' }}
                                        id="status"
                                        label="Status"
                                        disabled
                                        defaultValue={"Aktif"}
                                        inputProps={{
                                            style: {
                                                fontSize: 11
                                            }
                                        }}
                                        InputLabelProps={{
                                            style: {
                                                fontSize: 11,
                                                color: '#7e8085'
                                            }
                                        }}
                                    >
                                    </TextField>
                                </div>
                            </div>
                            {/* <div className="column-2">
                                <div className="margin-top-10px" style={{ marginTop: 8 }}>
                                    <TextField
                                        style={{ width: '100%' }}
                                        id="max-value"
                                        label="Max Value"
                                        // value={this.state.periode}
                                    >
                                    </TextField>
                                </div>
                            </div> */}
                        </div>
                        <div className="margin-top-10px" style={{ padding: 10, paddingLeft: 0 }}>
                            <Typography style={{ fontSize: 11 }}>{`Dibuat  : ${format(this.state.date, 'dd MMMM yyyy', {locale: localeID})}`}</Typography>
                            {/* <Typography style={{ fontSize: 11 }}>Diubah	: Admin - 21 Jul 2020, 18:45</Typography> */}
                        </div>
                    </div>
                    <div className="border-top grid grid-2x" style={{ height: 56, backgroundColor: '#f5f5f5', paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1" style={{ alignSelf: 'center' }}>
                            <div onClick={() => this.props.onClickClose()} style={{ width: 102, height: 30, border: 'solid 1px #354960', borderRadius: 5, alignItems: 'center', display: 'flex', justifyContent: 'center', cursor:"pointer" }}>
                                <span style={{ color: '#354960', fontSize: 11 }} >Batal</span>
                            </div>
                        </div>
                        <div className="column-2" style={{display: 'flex', justifyContent: 'flex-end', alignItems: 'center'}}>
                            <div onClick={() => this.validasi()} style={{ width: 102, height: 30, backgroundColor: '#354960', borderRadius: 5, alignItems: 'center', display: 'flex', justifyContent: 'center', cursor:"pointer" }}>
                                <span style={{ color: '#fff', fontSize: 11 }}>Simpan</span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        );
    }
}
